Learn R Programming

lmerPerm (version 0.1.9)

permute_fun: This function defines the permutation strategry

Description

perform permuation on response variable i.e. y, using the stop criterion suggested by Anscombe

Usage

permute_fun(data, mle)

Value

A data frame containing the data with a permuted y.

Arguments

data

A data frame specifying the data to be analysed.

mle

A string that indicated response variable

Examples

Run this code
data<-mtcars
permute<-permute_fun(data=data,mle='mpg')

Run the code above in your browser using DataLab