powered by
perform permuation on response variable i.e. y, using the stop criterion suggested by Anscombe
permute_fun(data, mle)
A data frame containing the data with a permuted y.
A data frame specifying the data to be analysed.
A string that indicated response variable
data<-mtcars permute<-permute_fun(data=data,mle='mpg')
Run the code above in your browser using DataLab